@@ -25,18 +25,20 @@
 #define SRCINST_CALLBACK_H
 
 struct _callback_list {
-  int count;
-  struct _callback_node* first;
+    int count;
+    struct _callback_node *first;
 };
 
 struct _callback_node {
-  srcinst_callback callback;
-  struct _callback_node* next;
+    srcinst_callback callback;
+    struct _callback_node *next;
 };
 
-void _init_callback_list(struct _callback_list* list);
-void _add_callback_list(struct _callback_list* list, srcinst_callback callback);
-void _remove_callback_list(struct _callback_list* list, srcinst_callback callback);
-void _fini_callback_list(struct _callback_list* list);
+void _init_callback_list(struct _callback_list *list);
+void _add_callback_list(struct _callback_list *list,
+			srcinst_callback callback);
+void _remove_callback_list(struct _callback_list *list,
+			   srcinst_callback callback);
+void _fini_callback_list(struct _callback_list *list);
 
-#endif /* SRCINST_CALLBACK_H */
+#endif				/* SRCINST_CALLBACK_H */
