@@ -28,20 +28,21 @@
 /* In fact it is a simple char** with a counter and some functions.  */
 
 struct srcinst_string_list {
-  size_t count;
-  char** strings;
+    size_t count;
+    char **strings;
 };
 
 /* the following function just sets ->count and ->strings to 0 */
-void srcinst_init_string_list(struct srcinst_string_list* list);
+void srcinst_init_string_list(struct srcinst_string_list *list);
 
 /* the following function unallocates the strings and ->strings.
    (char*)0 strings are skipped. */
-void srcinst_free_string_list(struct srcinst_string_list* list);
+void srcinst_free_string_list(struct srcinst_string_list *list);
 
 /* init a string LIST globbing a certain DIRECTORY. PATTERN is a shell
    wildcard pattern. Entries '.' and '..' are not included in the glob */
-int srcinst_glob_string_list(struct srcinst_string_list* list, char* dirname, char* pattern);
+int srcinst_glob_string_list(struct srcinst_string_list *list,
+			     char *dirname, char *pattern);
 
 /* the following is relatively slow, it reallocs ->strings to add a new
    element. If you want a faster way to build a list, prepare the char** and
@@ -51,11 +52,12 @@ int srcinst_glob_string_list(struct srcinst_string_list* list, char* dirname, ch
    However, do not call functions different than srcinst_free_string afterwards
    or you will get nice SIGSEGV */
 
-void srcinst_add_string_list(struct srcinst_string_list* list, char* string);
+void srcinst_add_string_list(struct srcinst_string_list *list,
+			     char *string);
 
 /* deep copy SRC string list to DEST */
-void srcinst_copy_string_list(struct srcinst_string_list* dest,
-			      struct srcinst_string_list* src);
+void srcinst_copy_string_list(struct srcinst_string_list *dest,
+			      struct srcinst_string_list *src);
 
 /* this is a variation, where only the ->strings array is allocated, while
    the strings are only mirrored by copying the pointers.
@@ -63,23 +65,25 @@ void srcinst_copy_string_list(struct srcinst_string_list* dest,
    use for performance when needed.
 */
 
-void srcinst_mirror_string_list(struct srcinst_string_list* dest,
-				struct srcinst_string_list* src);
+void srcinst_mirror_string_list(struct srcinst_string_list *dest,
+				struct srcinst_string_list *src);
 
 /* the following function purges a filelist from "" and, optionally,
    non-existing files. */
 
-void srcinst_purge_string_list(struct srcinst_string_list* l, int nonexistant);
+void srcinst_purge_string_list(struct srcinst_string_list *l,
+			       int nonexistant);
 
 /* returns a newly allocated string that is the concatenation of all
    strings in list L, separated by string SEP */
 
-char* srcinst_collapse_string_list(struct srcinst_string_list* l, char* sep);
+char *srcinst_collapse_string_list(struct srcinst_string_list *l,
+				   char *sep);
 
 
 /* sort a string list using the compare function passed as argument COMPARE */
-void srcinst_sort_string_list(struct srcinst_string_list* list,
-			      int (*compare)(char**, char**));
+void srcinst_sort_string_list(struct srcinst_string_list *list,
+			      int (*compare) (char **, char **));
 
 /* a search function is not needed.
    Define your order in the string list, then use srcinst_bsearch.
@@ -88,8 +92,8 @@ void srcinst_sort_string_list(struct srcinst_string_list* list,
 */
 
 /* prefix each element of the string list with the argument PREFIX */
-void srcinst_prefix_string_list(struct srcinst_string_list* l, char* prefix);
+void srcinst_prefix_string_list(struct srcinst_string_list *l,
+				char *prefix);
 
 
-#endif /* SRCINST_STRING_LIST_H */
-
+#endif				/* SRCINST_STRING_LIST_H */
